@@ -1,8 +1,9 @@
+from .event import Event
 from .state import State
 from .statemachine import StateMachine
 
 __author__ = """Fernando Macedo"""
 __email__ = "fgmacedo@gmail.com"
-__version__ = "2.3.5"
+__version__ = "2.4.0"
 
-__all__ = ["StateMachine", "State"]
+__all__ = ["StateMachine", "State", "Event"]
