@@ -3,8 +3,9 @@ from typing import Any
 from typing import Dict
 from weakref import ref
 
-from .callbacks import CallbackMetaList
+from .callbacks import CallbackGroup
 from .callbacks import CallbackPriority
+from .callbacks import CallbackSpecList
 from .exceptions import StateMachineError
 from .i18n import _
 from .transition import Transition
@@ -91,6 +92,13 @@ class State:
     >>> [(t.source.name, t.target.name) for t in transitions]
     [('Draft', 'Draft'), ('Draft', 'Producing'), ('Draft', 'Closed')]
 
+    Sometimes it's easier to use the :func:`State.from_` method:
+
+    >>> transitions = closed.from_(draft, producing, closed)
+
+    >>> [(t.source.name, t.target.name) for t in transitions]
+    [('Draft', 'Closed'), ('Producing', 'Closed'), ('Closed', 'Closed')]
+
     """
 
     def __init__(
@@ -108,8 +116,13 @@ class State:
         self._final = final
         self._id: str = ""
         self.transitions = TransitionList()
-        self.enter = CallbackMetaList().add(enter, priority=CallbackPriority.INLINE)
-        self.exit = CallbackMetaList().add(exit, priority=CallbackPriority.INLINE)
+        self._specs = CallbackSpecList()
+        self.enter = self._specs.grouper(CallbackGroup.ENTER).add(
+            enter, priority=CallbackPriority.INLINE
+        )
+        self.exit = self._specs.grouper(CallbackGroup.EXIT).add(
+            exit, priority=CallbackPriority.INLINE
+        )
 
     def __eq__(self, other):
         return isinstance(other, State) and self.name == other.name and self.id == other.id
@@ -118,20 +131,10 @@ class State:
         return hash(repr(self))
 
     def _setup(self):
-        self.enter.add("on_enter_state", priority=CallbackPriority.GENERIC, suppress_errors=True)
-        self.enter.add(
-            f"on_enter_{self.id}", priority=CallbackPriority.NAMING, suppress_errors=True
-        )
-        self.exit.add("on_exit_state", priority=CallbackPriority.GENERIC, suppress_errors=True)
-        self.exit.add(f"on_exit_{self.id}", priority=CallbackPriority.NAMING, suppress_errors=True)
-
-    def _add_observer(self, register):
-        register(self.enter)
-        register(self.exit)
-
-    def _check_callbacks(self, check):
-        check(self.enter)
-        check(self.exit)
+        self.enter.add("on_enter_state", priority=CallbackPriority.GENERIC, is_convention=True)
+        self.enter.add(f"on_enter_{self.id}", priority=CallbackPriority.NAMING, is_convention=True)
+        self.exit.add("on_exit_state", priority=CallbackPriority.GENERIC, is_convention=True)
+        self.exit.add(f"on_exit_{self.id}", priority=CallbackPriority.NAMING, is_convention=True)
 
     def __repr__(self):
         return (
